"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.waitForChannelReady = exports.createChannel = void 0;
const grpc_js_1 = require("@grpc/grpc-js");
const knownProtocols = new Set(['http', 'https']);
function createChannel(address, credentials, options = {}) {
    const match = /^(?:([^:]+):\/\/)?(.*?)(?::(\d+))?$/.exec(address);
    if (match == null)
        throw new Error(`Invalid address: '${address}'`);
    let [, protocol, host, port] = match;
    const knownProtocol = !protocol || knownProtocols.has(protocol);
    const isSecure = credentials?._isSecure() || protocol?.includes('https');
    credentials ?? (credentials = isSecure
        ? grpc_js_1.ChannelCredentials.createSsl()
        : grpc_js_1.ChannelCredentials.createInsecure());
    port ?? (port = isSecure ? '443' : '80');
    let target = knownProtocol ? `${host}:${port}` : address;
    return new grpc_js_1.Channel(target, credentials, options);
}
exports.createChannel = createChannel;
async function waitForChannelReady(channel, deadline) {
    while (true) {
        const state = channel.getConnectivityState(true);
        if (state === grpc_js_1.connectivityState.READY) {
            return;
        }
        await new Promise((resolve, reject) => {
            channel.watchConnectivityState(state, deadline, err => {
                if (err != null) {
                    reject(err);
                }
                else {
                    resolve();
                }
            });
        });
    }
}
exports.waitForChannelReady = waitForChannelReady;
//# sourceMappingURL=channel.js.map